A vector with the estimated rate of correct classification for every fold.
percent
A matrix with the mean estimated rates of correct classification.
runtime
The time required by the cross-validation procedure.
Arguments
x
A matrix with the data.
ina
A group indicator variable for the avaiable data.
nfolds
The number of folds in the cross validation.
folds
If you have the list with the folds supply it here. You can also leave it NULL and it will create folds.
quantile.used
A number, the minimum number of the data points regarded as good points.
nsamp
The number of samples or "best", "exact", or "sample". The limit If "sample" the number chosen is min(5 * p, 3000), taken from Rousseeuw and Hubert (1997). If "best" exhaustive enumeration is done up to 5000 samples: if "exact" exhaustive enumeration will be attempted.
stratified
Do you want the folds to be created in a stratified way? TRUE or FALSE.
seed
You can specify your own seed number here or leave it NULL.
Author
Michail Tsagris.
R implementation and documentation: Michail Tsagris mtsagris@uoc.gr.
Details
Cross validation is performed to estimate the rate of accuracy in the robust quadratic discriminant analysis.
References
Friedman Jerome, Trevor Hastie and Robert Tibshirani (2009).
The elements of statistical learning, 2nd edition. Springer, Berlin.